datanommer.models
=================

.. split here

This package contains the SQLAlchemy data model for datanommer.

Datanommer is a storage consumer for the Fedora Infrastructure Message Bus
(fedmsg).  It is comprised of a `fedmsg <http://fedmsg.com>`_ consumer that
stuffs every message into a sqlalchemy database.
